@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,33 +14,36 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gaming_v1.services.game_server_clusters_service import pagers
-from google.cloud.gaming_v1.types import common
-from google.cloud.gaming_v1.types import game_server_clusters
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import GameServerClustersServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.gaming_v1.services.game_server_clusters_service import pagers
+from google.cloud.gaming_v1.types import common, game_server_clusters
+
+from .transports.base import DEFAULT_CLIENT_INFO, GameServerClustersServiceTransport
 from .transports.grpc import GameServerClustersServiceGrpcTransport
 from .transports.grpc_asyncio import GameServerClustersServiceGrpcAsyncIOTransport
 
@@ -60,7 +63,8 @@ class GameServerClustersServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = GameServerClustersServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[GameServerClustersServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -169,11 +173,17 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
 
     @staticmethod
     def game_server_cluster_path(
-        project: str, location: str, realm: str, cluster: str,
+        project: str,
+        location: str,
+        realm: str,
+        cluster: str,
     ) -> str:
         """Returns a fully-qualified game_server_cluster string."""
         return "projects/{project}/locations/{location}/realms/{realm}/gameServerClusters/{cluster}".format(
-            project=project, location=location, realm=realm, cluster=cluster,
+            project=project,
+            location=location,
+            realm=realm,
+            cluster=cluster,
         )
 
     @staticmethod
@@ -186,7 +196,9 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -199,9 +211,13 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -210,9 +226,13 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -221,9 +241,13 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -232,10 +256,14 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -244,6 +272,73 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -294,50 +389,22 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, GameServerClustersServiceTransport):
             # transport is a GameServerClustersServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -349,6 +416,15 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -359,6 +435,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_game_server_clusters(
@@ -373,6 +450,33 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         r"""Lists game server clusters in a given project and
         location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_list_game_server_clusters():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.ListGameServerClustersRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_game_server_clusters(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.ListGameServerClustersRequest, dict]):
                 The request object. Request message for
@@ -401,7 +505,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -434,12 +538,20 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListGameServerClustersPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -456,6 +568,32 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
     ) -> game_server_clusters.GameServerCluster:
         r"""Gets details of a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_get_game_server_cluster():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.GetGameServerClusterRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.GetGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -479,7 +617,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
                 A game server cluster resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -510,7 +648,12 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -531,6 +674,41 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         r"""Creates a new game server cluster in a given project
         and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_create_game_server_cluster():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1.CreateGameServerClusterRequest(
+                    parent="parent_value",
+                    game_server_cluster_id="game_server_cluster_id_value",
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                operation = client.create_game_server_cluster(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.CreateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -573,7 +751,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [parent, game_server_cluster, game_server_cluster_id]
@@ -612,7 +790,12 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -638,6 +821,37 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         r"""Previews creation of a new game server cluster in a
         given project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_preview_create_game_server_cluster():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1.PreviewCreateGameServerClusterRequest(
+                    parent="parent_value",
+                    game_server_cluster_id="game_server_cluster_id_value",
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                response = client.preview_create_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.PreviewCreateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -679,7 +893,12 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -697,6 +916,36 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
     ) -> operation.Operation:
         r"""Deletes a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_delete_game_server_cluster():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.DeleteGameServerClusterRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_game_server_cluster(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.DeleteGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -730,12 +979,9 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -768,7 +1014,12 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -793,6 +1044,32 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
     ) -> game_server_clusters.PreviewDeleteGameServerClusterResponse:
         r"""Previews deletion of a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_preview_delete_game_server_cluster():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.PreviewDeleteGameServerClusterRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.preview_delete_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.PreviewDeleteGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -834,7 +1111,12 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -853,6 +1135,39 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
     ) -> operation.Operation:
         r"""Patches a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_update_game_server_cluster():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1.UpdateGameServerClusterRequest(
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                operation = client.update_game_server_cluster(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.UpdateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -889,7 +1204,7 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([game_server_cluster, update_mask])
         if request is not None and has_flattened_params:
@@ -926,7 +1241,12 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -951,6 +1271,35 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
     ) -> game_server_clusters.PreviewUpdateGameServerClusterResponse:
         r"""Previews updating a GameServerCluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_preview_update_game_server_cluster():
+                # Create a client
+                client = gaming_v1.GameServerClustersServiceClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1.PreviewUpdateGameServerClusterRequest(
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                response = client.preview_update_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.PreviewUpdateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -994,7 +1343,12 @@ class GameServerClustersServiceClient(metaclass=GameServerClustersServiceClientM
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
