@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,28 +16,32 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gaming_v1.services.game_server_configs_service import pagers
-from google.cloud.gaming_v1.types import common
-from google.cloud.gaming_v1.types import game_server_configs
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import GameServerConfigsServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import GameServerConfigsServiceGrpcAsyncIOTransport
+
+from google.cloud.gaming_v1.services.game_server_configs_service import pagers
+from google.cloud.gaming_v1.types import common, game_server_configs
+
 from .client import GameServerConfigsServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, GameServerConfigsServiceTransport
+from .transports.grpc_asyncio import GameServerConfigsServiceGrpcAsyncIOTransport
 
 
 class GameServerConfigsServiceAsyncClient:
@@ -118,6 +122,42 @@ class GameServerConfigsServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return GameServerConfigsServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> GameServerConfigsServiceTransport:
         """Returns the transport used by the client instance.
@@ -191,6 +231,33 @@ class GameServerConfigsServiceAsyncClient:
         r"""Lists game server configs in a given project,
         location, and game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_list_game_server_configs():
+                # Create a client
+                client = gaming_v1.GameServerConfigsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.ListGameServerConfigsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_game_server_configs(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.ListGameServerConfigsRequest, dict]):
                 The request object. Request message for
@@ -219,7 +286,7 @@ class GameServerConfigsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -259,12 +326,20 @@ class GameServerConfigsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListGameServerConfigsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -281,6 +356,32 @@ class GameServerConfigsServiceAsyncClient:
     ) -> game_server_configs.GameServerConfig:
         r"""Gets details of a single game server config.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_get_game_server_config():
+                # Create a client
+                client = gaming_v1.GameServerConfigsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.GetGameServerConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_game_server_config(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.GetGameServerConfigRequest, dict]):
                 The request object. Request message for
@@ -304,7 +405,7 @@ class GameServerConfigsServiceAsyncClient:
                 A game server config resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -344,7 +445,12 @@ class GameServerConfigsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -365,6 +471,37 @@ class GameServerConfigsServiceAsyncClient:
         referenced in the game server deployment rollout
         resource.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_create_game_server_config():
+                # Create a client
+                client = gaming_v1.GameServerConfigsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.CreateGameServerConfigRequest(
+                    parent="parent_value",
+                    config_id="config_id_value",
+                )
+
+                # Make the request
+                operation = client.create_game_server_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.CreateGameServerConfigRequest, dict]):
                 The request object. Request message for
@@ -400,7 +537,7 @@ class GameServerConfigsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, game_server_config])
         if request is not None and has_flattened_params:
@@ -433,7 +570,12 @@ class GameServerConfigsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -459,6 +601,36 @@ class GameServerConfigsServiceAsyncClient:
         will fail if the game server config is referenced in a
         game server deployment rollout.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_delete_game_server_config():
+                # Create a client
+                client = gaming_v1.GameServerConfigsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.DeleteGameServerConfigRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_game_server_config(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.DeleteGameServerConfigRequest, dict]):
                 The request object. Request message for
@@ -492,12 +664,9 @@ class GameServerConfigsServiceAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -528,7 +697,12 @@ class GameServerConfigsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
