@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,29 +16,33 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gaming_v1.services.realms_service import pagers
-from google.cloud.gaming_v1.types import common
-from google.cloud.gaming_v1.types import realms
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import RealmsServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import RealmsServiceGrpcAsyncIOTransport
+
+from google.cloud.gaming_v1.services.realms_service import pagers
+from google.cloud.gaming_v1.types import common, realms
+
 from .client import RealmsServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, RealmsServiceTransport
+from .transports.grpc_asyncio import RealmsServiceGrpcAsyncIOTransport
 
 
 class RealmsServiceAsyncClient:
@@ -111,6 +115,42 @@ class RealmsServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return RealmsServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> RealmsServiceTransport:
         """Returns the transport used by the client instance.
@@ -182,6 +222,33 @@ class RealmsServiceAsyncClient:
     ) -> pagers.ListRealmsAsyncPager:
         r"""Lists realms in a given project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_list_realms():
+                # Create a client
+                client = gaming_v1.RealmsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.ListRealmsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_realms(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.ListRealmsRequest, dict]):
                 The request object. Request message for
@@ -209,7 +276,7 @@ class RealmsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -249,12 +316,20 @@ class RealmsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListRealmsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -271,6 +346,32 @@ class RealmsServiceAsyncClient:
     ) -> realms.Realm:
         r"""Gets details of a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_get_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.GetRealmRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_realm(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.GetRealmRequest, dict]):
                 The request object. Request message for
@@ -294,7 +395,7 @@ class RealmsServiceAsyncClient:
                 A realm resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -334,7 +435,12 @@ class RealmsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -352,6 +458,41 @@ class RealmsServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new realm in a given project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_create_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                realm = gaming_v1.Realm()
+                realm.time_zone = "time_zone_value"
+
+                request = gaming_v1.CreateRealmRequest(
+                    parent="parent_value",
+                    realm_id="realm_id_value",
+                    realm=realm,
+                )
+
+                # Make the request
+                operation = client.create_realm(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.CreateRealmRequest, dict]):
                 The request object. Request message for
@@ -393,7 +534,7 @@ class RealmsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, realm, realm_id])
         if request is not None and has_flattened_params:
@@ -428,7 +569,12 @@ class RealmsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -452,6 +598,36 @@ class RealmsServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_delete_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.DeleteRealmRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_realm(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.DeleteRealmRequest, dict]):
                 The request object. Request message for
@@ -485,12 +661,9 @@ class RealmsServiceAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -521,7 +694,12 @@ class RealmsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -546,6 +724,39 @@ class RealmsServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Patches a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_update_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                realm = gaming_v1.Realm()
+                realm.time_zone = "time_zone_value"
+
+                request = gaming_v1.UpdateRealmRequest(
+                    realm=realm,
+                )
+
+                # Make the request
+                operation = client.update_realm(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.UpdateRealmRequest, dict]):
                 The request object. Request message for
@@ -581,7 +792,7 @@ class RealmsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([realm, update_mask])
         if request is not None and has_flattened_params:
@@ -616,7 +827,12 @@ class RealmsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -639,6 +855,35 @@ class RealmsServiceAsyncClient:
     ) -> realms.PreviewRealmUpdateResponse:
         r"""Previews patches to a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            async def sample_preview_realm_update():
+                # Create a client
+                client = gaming_v1.RealmsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                realm = gaming_v1.Realm()
+                realm.time_zone = "time_zone_value"
+
+                request = gaming_v1.PreviewRealmUpdateRequest(
+                    realm=realm,
+                )
+
+                # Make the request
+                response = await client.preview_realm_update(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.PreviewRealmUpdateRequest, dict]):
                 The request object. Request message for
@@ -684,7 +929,12 @@ class RealmsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
