@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,33 +14,36 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gaming_v1.services.realms_service import pagers
-from google.cloud.gaming_v1.types import common
-from google.cloud.gaming_v1.types import realms
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import RealmsServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.gaming_v1.services.realms_service import pagers
+from google.cloud.gaming_v1.types import common, realms
+
+from .transports.base import DEFAULT_CLIENT_INFO, RealmsServiceTransport
 from .transports.grpc import RealmsServiceGrpcTransport
 from .transports.grpc_asyncio import RealmsServiceGrpcAsyncIOTransport
 
@@ -57,7 +60,10 @@ class RealmsServiceClientMeta(type):
     _transport_registry["grpc"] = RealmsServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = RealmsServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[RealmsServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[RealmsServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -164,10 +170,16 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def realm_path(project: str, location: str, realm: str,) -> str:
+    def realm_path(
+        project: str,
+        location: str,
+        realm: str,
+    ) -> str:
         """Returns a fully-qualified realm string."""
         return "projects/{project}/locations/{location}/realms/{realm}".format(
-            project=project, location=location, realm=realm,
+            project=project,
+            location=location,
+            realm=realm,
         )
 
     @staticmethod
@@ -180,7 +192,9 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -193,9 +207,13 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -204,9 +222,13 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -215,9 +237,13 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -226,10 +252,14 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -238,6 +268,73 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -288,50 +385,22 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, RealmsServiceTransport):
             # transport is a RealmsServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -343,6 +412,15 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -353,6 +431,7 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_realms(
@@ -366,6 +445,33 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
     ) -> pagers.ListRealmsPager:
         r"""Lists realms in a given project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_list_realms():
+                # Create a client
+                client = gaming_v1.RealmsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.ListRealmsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_realms(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.ListRealmsRequest, dict]):
                 The request object. Request message for
@@ -393,7 +499,7 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -424,12 +530,20 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListRealmsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -446,6 +560,32 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
     ) -> realms.Realm:
         r"""Gets details of a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_get_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.GetRealmRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_realm(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.GetRealmRequest, dict]):
                 The request object. Request message for
@@ -469,7 +609,7 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
                 A realm resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -500,7 +640,12 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -518,6 +663,41 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
     ) -> operation.Operation:
         r"""Creates a new realm in a given project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_create_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceClient()
+
+                # Initialize request argument(s)
+                realm = gaming_v1.Realm()
+                realm.time_zone = "time_zone_value"
+
+                request = gaming_v1.CreateRealmRequest(
+                    parent="parent_value",
+                    realm_id="realm_id_value",
+                    realm=realm,
+                )
+
+                # Make the request
+                operation = client.create_realm(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.CreateRealmRequest, dict]):
                 The request object. Request message for
@@ -559,7 +739,7 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, realm, realm_id])
         if request is not None and has_flattened_params:
@@ -594,7 +774,12 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -618,6 +803,36 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_delete_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1.DeleteRealmRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_realm(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.DeleteRealmRequest, dict]):
                 The request object. Request message for
@@ -651,12 +866,9 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -687,7 +899,12 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -712,6 +929,39 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
     ) -> operation.Operation:
         r"""Patches a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_update_realm():
+                # Create a client
+                client = gaming_v1.RealmsServiceClient()
+
+                # Initialize request argument(s)
+                realm = gaming_v1.Realm()
+                realm.time_zone = "time_zone_value"
+
+                request = gaming_v1.UpdateRealmRequest(
+                    realm=realm,
+                )
+
+                # Make the request
+                operation = client.update_realm(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.UpdateRealmRequest, dict]):
                 The request object. Request message for
@@ -747,7 +997,7 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([realm, update_mask])
         if request is not None and has_flattened_params:
@@ -782,7 +1032,12 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -805,6 +1060,35 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
     ) -> realms.PreviewRealmUpdateResponse:
         r"""Previews patches to a single realm.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1
+
+            def sample_preview_realm_update():
+                # Create a client
+                client = gaming_v1.RealmsServiceClient()
+
+                # Initialize request argument(s)
+                realm = gaming_v1.Realm()
+                realm.time_zone = "time_zone_value"
+
+                request = gaming_v1.PreviewRealmUpdateRequest(
+                    realm=realm,
+                )
+
+                # Make the request
+                response = client.preview_realm_update(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1.types.PreviewRealmUpdateRequest, dict]):
                 The request object. Request message for
@@ -842,7 +1126,12 @@ class RealmsServiceClient(metaclass=RealmsServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
