@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.gaming.v1",
@@ -66,7 +64,7 @@ class OperationMetadata(proto.Message):
         unreachable (Sequence[str]):
             Output only. List of Locations that could not
             be reached.
-        operation_status (Sequence[google.cloud.gaming_v1.types.OperationMetadata.OperationStatusEntry]):
+        operation_status (Mapping[str, google.cloud.gaming_v1.types.OperationStatus]):
             Output only. Operation status for Game
             Services API operations. Operation status is in
             the form of key-value pairs where keys are
@@ -75,16 +73,45 @@ class OperationMetadata(proto.Message):
             includes an error code and error message.
     """
 
-    create_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    target = proto.Field(proto.STRING, number=3,)
-    verb = proto.Field(proto.STRING, number=4,)
-    status_message = proto.Field(proto.STRING, number=5,)
-    requested_cancellation = proto.Field(proto.BOOL, number=6,)
-    api_version = proto.Field(proto.STRING, number=7,)
-    unreachable = proto.RepeatedField(proto.STRING, number=8,)
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    target = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    verb = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    status_message = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    requested_cancellation = proto.Field(
+        proto.BOOL,
+        number=6,
+    )
+    api_version = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=8,
+    )
     operation_status = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=9, message="OperationStatus",
+        proto.STRING,
+        proto.MESSAGE,
+        number=9,
+        message="OperationStatus",
     )
 
 
@@ -108,20 +135,34 @@ class OperationStatus(proto.Message):
         PERMISSION_DENIED = 2
         CLUSTER_CONNECTION = 3
 
-    done = proto.Field(proto.BOOL, number=1,)
-    error_code = proto.Field(proto.ENUM, number=2, enum=ErrorCode,)
-    error_message = proto.Field(proto.STRING, number=3,)
+    done = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
+    error_code = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=ErrorCode,
+    )
+    error_message = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class LabelSelector(proto.Message):
     r"""The label selector, used to group labels on the resources.
 
     Attributes:
-        labels (Sequence[google.cloud.gaming_v1.types.LabelSelector.LabelsEntry]):
+        labels (Mapping[str, str]):
             Resource labels for this selector.
     """
 
-    labels = proto.MapField(proto.STRING, proto.STRING, number=1,)
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=1,
+    )
 
 
 class RealmSelector(proto.Message):
@@ -132,7 +173,10 @@ class RealmSelector(proto.Message):
             List of realms to match.
     """
 
-    realms = proto.RepeatedField(proto.STRING, number=1,)
+    realms = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
 
 
 class Schedule(proto.Message):
@@ -164,12 +208,25 @@ class Schedule(proto.Message):
             realm.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
     cron_job_duration = proto.Field(
-        proto.MESSAGE, number=3, message=duration_pb2.Duration,
+        proto.MESSAGE,
+        number=3,
+        message=duration_pb2.Duration,
+    )
+    cron_spec = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    cron_spec = proto.Field(proto.STRING, number=4,)
 
 
 class SpecSource(proto.Message):
@@ -186,8 +243,14 @@ class SpecSource(proto.Message):
             or Agones autoscaler spec.
     """
 
-    game_server_config_name = proto.Field(proto.STRING, number=1,)
-    name = proto.Field(proto.STRING, number=2,)
+    game_server_config_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class TargetDetails(proto.Message):
@@ -227,8 +290,15 @@ class TargetDetails(proto.Message):
                     spec. The Agones fleet spec source.
             """
 
-            name = proto.Field(proto.STRING, number=1,)
-            spec_source = proto.Field(proto.MESSAGE, number=2, message="SpecSource",)
+            name = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            spec_source = proto.Field(
+                proto.MESSAGE,
+                number=2,
+                message="SpecSource",
+            )
 
         class TargetFleetAutoscaler(proto.Message):
             r"""Target Agones autoscaler policy reference.
@@ -241,8 +311,15 @@ class TargetDetails(proto.Message):
                     spec. Details about the Agones autoscaler spec.
             """
 
-            name = proto.Field(proto.STRING, number=1,)
-            spec_source = proto.Field(proto.MESSAGE, number=2, message="SpecSource",)
+            name = proto.Field(
+                proto.STRING,
+                number=1,
+            )
+            spec_source = proto.Field(
+                proto.MESSAGE,
+                number=2,
+                message="SpecSource",
+            )
 
         fleet = proto.Field(
             proto.MESSAGE,
@@ -255,10 +332,18 @@ class TargetDetails(proto.Message):
             message="TargetDetails.TargetFleetDetails.TargetFleetAutoscaler",
         )
 
-    game_server_cluster_name = proto.Field(proto.STRING, number=1,)
-    game_server_deployment_name = proto.Field(proto.STRING, number=2,)
+    game_server_cluster_name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    game_server_deployment_name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     fleet_details = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=TargetFleetDetails,
+        proto.MESSAGE,
+        number=3,
+        message=TargetFleetDetails,
     )
 
 
@@ -270,7 +355,11 @@ class TargetState(proto.Message):
             Details about Agones fleets.
     """
 
-    details = proto.RepeatedField(proto.MESSAGE, number=1, message="TargetDetails",)
+    details = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="TargetDetails",
+    )
 
 
 class DeployedFleetDetails(proto.Message):
@@ -324,14 +413,36 @@ class DeployedFleetDetails(proto.Message):
                     replicas in this fleet.
             """
 
-            ready_replicas = proto.Field(proto.INT64, number=1,)
-            allocated_replicas = proto.Field(proto.INT64, number=2,)
-            reserved_replicas = proto.Field(proto.INT64, number=3,)
-            replicas = proto.Field(proto.INT64, number=4,)
+            ready_replicas = proto.Field(
+                proto.INT64,
+                number=1,
+            )
+            allocated_replicas = proto.Field(
+                proto.INT64,
+                number=2,
+            )
+            reserved_replicas = proto.Field(
+                proto.INT64,
+                number=3,
+            )
+            replicas = proto.Field(
+                proto.INT64,
+                number=4,
+            )
 
-        fleet = proto.Field(proto.STRING, number=1,)
-        fleet_spec = proto.Field(proto.STRING, number=2,)
-        spec_source = proto.Field(proto.MESSAGE, number=3, message="SpecSource",)
+        fleet = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        fleet_spec = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        spec_source = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message="SpecSource",
+        )
         status = proto.Field(
             proto.MESSAGE,
             number=5,
@@ -352,13 +463,29 @@ class DeployedFleetDetails(proto.Message):
                 The autoscaler spec retrieved from Agones.
         """
 
-        autoscaler = proto.Field(proto.STRING, number=1,)
-        spec_source = proto.Field(proto.MESSAGE, number=4, message="SpecSource",)
-        fleet_autoscaler_spec = proto.Field(proto.STRING, number=3,)
+        autoscaler = proto.Field(
+            proto.STRING,
+            number=1,
+        )
+        spec_source = proto.Field(
+            proto.MESSAGE,
+            number=4,
+            message="SpecSource",
+        )
+        fleet_autoscaler_spec = proto.Field(
+            proto.STRING,
+            number=3,
+        )
 
-    deployed_fleet = proto.Field(proto.MESSAGE, number=1, message=DeployedFleet,)
+    deployed_fleet = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=DeployedFleet,
+    )
     deployed_autoscaler = proto.Field(
-        proto.MESSAGE, number=2, message=DeployedFleetAutoscaler,
+        proto.MESSAGE,
+        number=2,
+        message=DeployedFleetAutoscaler,
     )
 
 
