@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,29 +16,33 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gaming_v1beta.services.game_server_clusters_service import pagers
-from google.cloud.gaming_v1beta.types import common
-from google.cloud.gaming_v1beta.types import game_server_clusters
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import GameServerClustersServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import GameServerClustersServiceGrpcAsyncIOTransport
+
+from google.cloud.gaming_v1beta.services.game_server_clusters_service import pagers
+from google.cloud.gaming_v1beta.types import common, game_server_clusters
+
 from .client import GameServerClustersServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, GameServerClustersServiceTransport
+from .transports.grpc_asyncio import GameServerClustersServiceGrpcAsyncIOTransport
 
 
 class GameServerClustersServiceAsyncClient:
@@ -121,6 +125,42 @@ class GameServerClustersServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return GameServerClustersServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> GameServerClustersServiceTransport:
         """Returns the transport used by the client instance.
@@ -194,6 +234,33 @@ class GameServerClustersServiceAsyncClient:
         r"""Lists game server clusters in a given project and
         location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_list_game_server_clusters():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.ListGameServerClustersRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_game_server_clusters(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.ListGameServerClustersRequest, dict]):
                 The request object. Request message for
@@ -222,7 +289,7 @@ class GameServerClustersServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -262,12 +329,20 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListGameServerClustersAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -284,6 +359,32 @@ class GameServerClustersServiceAsyncClient:
     ) -> game_server_clusters.GameServerCluster:
         r"""Gets details of a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_get_game_server_cluster():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.GetGameServerClusterRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.GetGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -308,7 +409,7 @@ class GameServerClustersServiceAsyncClient:
                 A game server cluster resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -348,7 +449,12 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -369,6 +475,41 @@ class GameServerClustersServiceAsyncClient:
         r"""Creates a new game server cluster in a given project
         and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_create_game_server_cluster():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1beta.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1beta.CreateGameServerClusterRequest(
+                    parent="parent_value",
+                    game_server_cluster_id="game_server_cluster_id_value",
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                operation = client.create_game_server_cluster(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.CreateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -410,7 +551,7 @@ class GameServerClustersServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any(
             [parent, game_server_cluster, game_server_cluster_id]
@@ -447,7 +588,12 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -473,6 +619,37 @@ class GameServerClustersServiceAsyncClient:
         r"""Previews creation of a new game server cluster in a
         given project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_preview_create_game_server_cluster():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1beta.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1beta.PreviewCreateGameServerClusterRequest(
+                    parent="parent_value",
+                    game_server_cluster_id="game_server_cluster_id_value",
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                response = await client.preview_create_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.PreviewCreateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -516,7 +693,12 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -534,6 +716,36 @@ class GameServerClustersServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_delete_game_server_cluster():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.DeleteGameServerClusterRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_game_server_cluster(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.DeleteGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -567,12 +779,9 @@ class GameServerClustersServiceAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -603,7 +812,12 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -628,6 +842,32 @@ class GameServerClustersServiceAsyncClient:
     ) -> game_server_clusters.PreviewDeleteGameServerClusterResponse:
         r"""Previews deletion of a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_preview_delete_game_server_cluster():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.PreviewDeleteGameServerClusterRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.preview_delete_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.PreviewDeleteGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -671,7 +911,12 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -690,6 +935,39 @@ class GameServerClustersServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Patches a single game server cluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_update_game_server_cluster():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1beta.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1beta.UpdateGameServerClusterRequest(
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                operation = client.update_game_server_cluster(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.UpdateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -728,7 +1006,7 @@ class GameServerClustersServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([game_server_cluster, update_mask])
         if request is not None and has_flattened_params:
@@ -763,7 +1041,12 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -788,6 +1071,35 @@ class GameServerClustersServiceAsyncClient:
     ) -> game_server_clusters.PreviewUpdateGameServerClusterResponse:
         r"""Previews updating a GameServerCluster.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_preview_update_game_server_cluster():
+                # Create a client
+                client = gaming_v1beta.GameServerClustersServiceAsyncClient()
+
+                # Initialize request argument(s)
+                game_server_cluster = gaming_v1beta.GameServerCluster()
+                game_server_cluster.name = "name_value"
+
+                request = gaming_v1beta.PreviewUpdateGameServerClusterRequest(
+                    game_server_cluster=game_server_cluster,
+                )
+
+                # Make the request
+                response = await client.preview_update_game_server_cluster(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.PreviewUpdateGameServerClusterRequest, dict]):
                 The request object. Request message for
@@ -833,7 +1145,12 @@ class GameServerClustersServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
