@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,29 +16,33 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gaming_v1beta.services.game_server_deployments_service import pagers
-from google.cloud.gaming_v1beta.types import common
-from google.cloud.gaming_v1beta.types import game_server_deployments
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import GameServerDeploymentsServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import GameServerDeploymentsServiceGrpcAsyncIOTransport
+
+from google.cloud.gaming_v1beta.services.game_server_deployments_service import pagers
+from google.cloud.gaming_v1beta.types import common, game_server_deployments
+
 from .client import GameServerDeploymentsServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, GameServerDeploymentsServiceTransport
+from .transports.grpc_asyncio import GameServerDeploymentsServiceGrpcAsyncIOTransport
 
 
 class GameServerDeploymentsServiceAsyncClient:
@@ -127,6 +131,42 @@ class GameServerDeploymentsServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return GameServerDeploymentsServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> GameServerDeploymentsServiceTransport:
         """Returns the transport used by the client instance.
@@ -202,6 +242,33 @@ class GameServerDeploymentsServiceAsyncClient:
         r"""Lists game server deployments in a given project and
         location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_list_game_server_deployments():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.ListGameServerDeploymentsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_game_server_deployments(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.ListGameServerDeploymentsRequest, dict]):
                 The request object. Request message for
@@ -229,7 +296,7 @@ class GameServerDeploymentsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -269,12 +336,20 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListGameServerDeploymentsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -293,6 +368,32 @@ class GameServerDeploymentsServiceAsyncClient:
     ) -> game_server_deployments.GameServerDeployment:
         r"""Gets details of a single game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_get_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.GetGameServerDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_game_server_deployment(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.GetGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -317,7 +418,7 @@ class GameServerDeploymentsServiceAsyncClient:
                 A game server deployment resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -357,7 +458,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -377,6 +483,37 @@ class GameServerDeploymentsServiceAsyncClient:
         r"""Creates a new game server deployment in a given
         project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_create_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.CreateGameServerDeploymentRequest(
+                    parent="parent_value",
+                    deployment_id="deployment_id_value",
+                )
+
+                # Make the request
+                operation = client.create_game_server_deployment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.CreateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -411,7 +548,7 @@ class GameServerDeploymentsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, game_server_deployment])
         if request is not None and has_flattened_params:
@@ -444,7 +581,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -470,6 +612,36 @@ class GameServerDeploymentsServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_delete_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.DeleteGameServerDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_game_server_deployment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.DeleteGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -504,12 +676,9 @@ class GameServerDeploymentsServiceAsyncClient:
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -540,7 +709,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -567,6 +741,35 @@ class GameServerDeploymentsServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Patches a game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_update_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.UpdateGameServerDeploymentRequest(
+                )
+
+                # Make the request
+                operation = client.update_game_server_deployment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -606,7 +809,7 @@ class GameServerDeploymentsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([game_server_deployment, update_mask])
         if request is not None and has_flattened_params:
@@ -641,7 +844,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -667,6 +875,32 @@ class GameServerDeploymentsServiceAsyncClient:
     ) -> game_server_deployments.GameServerDeploymentRollout:
         r"""Gets details a single game server deployment rollout.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_get_game_server_deployment_rollout():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.GetGameServerDeploymentRolloutRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_game_server_deployment_rollout(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.GetGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
@@ -694,7 +928,7 @@ class GameServerDeploymentsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -734,7 +968,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -759,6 +998,35 @@ class GameServerDeploymentsServiceAsyncClient:
         game_server_config_overrides field, that will also not result in
         an error.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_update_game_server_deployment_rollout():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.UpdateGameServerDeploymentRolloutRequest(
+                )
+
+                # Make the request
+                operation = client.update_game_server_deployment_rollout(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = await operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
@@ -798,7 +1066,7 @@ class GameServerDeploymentsServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([rollout, update_mask])
         if request is not None and has_flattened_params:
@@ -835,7 +1103,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -861,6 +1134,31 @@ class GameServerDeploymentsServiceAsyncClient:
         r"""Previews the game server deployment rollout. This API
         does not mutate the rollout resource.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_preview_game_server_deployment_rollout():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.PreviewGameServerDeploymentRolloutRequest(
+                )
+
+                # Make the request
+                response = await client.preview_game_server_deployment_rollout(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.PreviewGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
@@ -910,7 +1208,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -930,6 +1233,32 @@ class GameServerDeploymentsServiceAsyncClient:
         and Agones autoscalers, including fleets running an
         older version of the game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            async def sample_fetch_deployment_state():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceAsyncClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.FetchDeploymentStateRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.fetch_deployment_state(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.FetchDeploymentStateRequest, dict]):
                 The request object. Request message for
@@ -973,7 +1302,12 @@ class GameServerDeploymentsServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
