@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,33 +14,36 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.gaming_v1beta.services.game_server_deployments_service import pagers
-from google.cloud.gaming_v1beta.types import common
-from google.cloud.gaming_v1beta.types import game_server_deployments
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import GameServerDeploymentsServiceTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.gaming_v1beta.services.game_server_deployments_service import pagers
+from google.cloud.gaming_v1beta.types import common, game_server_deployments
+
+from .transports.base import DEFAULT_CLIENT_INFO, GameServerDeploymentsServiceTransport
 from .transports.grpc import GameServerDeploymentsServiceGrpcTransport
 from .transports.grpc_asyncio import GameServerDeploymentsServiceGrpcAsyncIOTransport
 
@@ -62,7 +65,8 @@ class GameServerDeploymentsServiceClientMeta(type):
     ] = GameServerDeploymentsServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[GameServerDeploymentsServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -173,11 +177,15 @@ class GameServerDeploymentsServiceClient(
 
     @staticmethod
     def game_server_deployment_path(
-        project: str, location: str, deployment: str,
+        project: str,
+        location: str,
+        deployment: str,
     ) -> str:
         """Returns a fully-qualified game_server_deployment string."""
         return "projects/{project}/locations/{location}/gameServerDeployments/{deployment}".format(
-            project=project, location=location, deployment=deployment,
+            project=project,
+            location=location,
+            deployment=deployment,
         )
 
     @staticmethod
@@ -191,11 +199,15 @@ class GameServerDeploymentsServiceClient(
 
     @staticmethod
     def game_server_deployment_rollout_path(
-        project: str, location: str, deployment: str,
+        project: str,
+        location: str,
+        deployment: str,
     ) -> str:
         """Returns a fully-qualified game_server_deployment_rollout string."""
         return "projects/{project}/locations/{location}/gameServerDeployments/{deployment}/rollout".format(
-            project=project, location=location, deployment=deployment,
+            project=project,
+            location=location,
+            deployment=deployment,
         )
 
     @staticmethod
@@ -208,7 +220,9 @@ class GameServerDeploymentsServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -221,9 +235,13 @@ class GameServerDeploymentsServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -232,9 +250,13 @@ class GameServerDeploymentsServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -243,9 +265,13 @@ class GameServerDeploymentsServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -254,10 +280,14 @@ class GameServerDeploymentsServiceClient(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -266,6 +296,73 @@ class GameServerDeploymentsServiceClient(
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -316,50 +413,22 @@ class GameServerDeploymentsServiceClient(
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, GameServerDeploymentsServiceTransport):
             # transport is a GameServerDeploymentsServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -371,6 +440,15 @@ class GameServerDeploymentsServiceClient(
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -381,6 +459,7 @@ class GameServerDeploymentsServiceClient(
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def list_game_server_deployments(
@@ -397,6 +476,33 @@ class GameServerDeploymentsServiceClient(
         r"""Lists game server deployments in a given project and
         location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_list_game_server_deployments():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.ListGameServerDeploymentsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_game_server_deployments(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.ListGameServerDeploymentsRequest, dict]):
                 The request object. Request message for
@@ -424,7 +530,7 @@ class GameServerDeploymentsServiceClient(
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -459,12 +565,20 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListGameServerDeploymentsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -483,6 +597,32 @@ class GameServerDeploymentsServiceClient(
     ) -> game_server_deployments.GameServerDeployment:
         r"""Gets details of a single game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_get_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.GetGameServerDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_game_server_deployment(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.GetGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -507,7 +647,7 @@ class GameServerDeploymentsServiceClient(
                 A game server deployment resource.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -542,7 +682,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -562,6 +707,37 @@ class GameServerDeploymentsServiceClient(
         r"""Creates a new game server deployment in a given
         project and location.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_create_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.CreateGameServerDeploymentRequest(
+                    parent="parent_value",
+                    deployment_id="deployment_id_value",
+                )
+
+                # Make the request
+                operation = client.create_game_server_deployment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.CreateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -596,7 +772,7 @@ class GameServerDeploymentsServiceClient(
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, game_server_deployment])
         if request is not None and has_flattened_params:
@@ -633,7 +809,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -659,6 +840,36 @@ class GameServerDeploymentsServiceClient(
     ) -> operation.Operation:
         r"""Deletes a single game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_delete_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.DeleteGameServerDeploymentRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_game_server_deployment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.DeleteGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -693,12 +904,9 @@ class GameServerDeploymentsServiceClient(
 
                       }
 
-                   The JSON representation for Empty is empty JSON
-                   object {}.
-
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -733,7 +941,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -760,6 +973,35 @@ class GameServerDeploymentsServiceClient(
     ) -> operation.Operation:
         r"""Patches a game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_update_game_server_deployment():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.UpdateGameServerDeploymentRequest(
+                )
+
+                # Make the request
+                operation = client.update_game_server_deployment(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRequest, dict]):
                 The request object. Request message for
@@ -799,7 +1041,7 @@ class GameServerDeploymentsServiceClient(
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([game_server_deployment, update_mask])
         if request is not None and has_flattened_params:
@@ -838,7 +1080,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -864,6 +1111,32 @@ class GameServerDeploymentsServiceClient(
     ) -> game_server_deployments.GameServerDeploymentRollout:
         r"""Gets details a single game server deployment rollout.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_get_game_server_deployment_rollout():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.GetGameServerDeploymentRolloutRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_game_server_deployment_rollout(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.GetGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
@@ -891,7 +1164,7 @@ class GameServerDeploymentsServiceClient(
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -928,7 +1201,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -953,6 +1231,35 @@ class GameServerDeploymentsServiceClient(
         game_server_config_overrides field, that will also not result in
         an error.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_update_game_server_deployment_rollout():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.UpdateGameServerDeploymentRolloutRequest(
+                )
+
+                # Make the request
+                operation = client.update_game_server_deployment_rollout(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.UpdateGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
@@ -992,7 +1299,7 @@ class GameServerDeploymentsServiceClient(
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([rollout, update_mask])
         if request is not None and has_flattened_params:
@@ -1033,7 +1340,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1059,6 +1371,31 @@ class GameServerDeploymentsServiceClient(
         r"""Previews the game server deployment rollout. This API
         does not mutate the rollout resource.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_preview_game_server_deployment_rollout():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.PreviewGameServerDeploymentRolloutRequest(
+                )
+
+                # Make the request
+                response = client.preview_game_server_deployment_rollout(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.PreviewGameServerDeploymentRolloutRequest, dict]):
                 The request object. Request message for
@@ -1104,7 +1441,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1124,6 +1466,32 @@ class GameServerDeploymentsServiceClient(
         and Agones autoscalers, including fleets running an
         older version of the game server deployment.
 
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud import gaming_v1beta
+
+            def sample_fetch_deployment_state():
+                # Create a client
+                client = gaming_v1beta.GameServerDeploymentsServiceClient()
+
+                # Initialize request argument(s)
+                request = gaming_v1beta.FetchDeploymentStateRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.fetch_deployment_state(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.gaming_v1beta.types.FetchDeploymentStateRequest, dict]):
                 The request object. Request message for
@@ -1159,7 +1527,12 @@ class GameServerDeploymentsServiceClient(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
