@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.gaming_v1beta.types import common
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.gaming.v1beta",
@@ -71,11 +70,26 @@ class ListGameServerClustersRequest(proto.Message):
             https://cloud.google.com/apis/design/design_patterns#sorting_order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListGameServerClustersResponse(proto.Message):
@@ -98,10 +112,18 @@ class ListGameServerClustersResponse(proto.Message):
         return self
 
     game_server_clusters = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="GameServerCluster",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerCluster",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=4,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=4,)
 
 
 class GetGameServerClusterRequest(proto.Message):
@@ -116,7 +138,10 @@ class GetGameServerClusterRequest(proto.Message):
             ``projects/{project}/locations/{location}/realms/{realm-id}/gameServerClusters/{cluster}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateGameServerClusterRequest(proto.Message):
@@ -135,10 +160,18 @@ class CreateGameServerClusterRequest(proto.Message):
             be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    game_server_cluster_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    game_server_cluster_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     game_server_cluster = proto.Field(
-        proto.MESSAGE, number=3, message="GameServerCluster",
+        proto.MESSAGE,
+        number=3,
+        message="GameServerCluster",
     )
 
 
@@ -161,13 +194,23 @@ class PreviewCreateGameServerClusterRequest(proto.Message):
             preview.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    game_server_cluster_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    game_server_cluster_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     game_server_cluster = proto.Field(
-        proto.MESSAGE, number=3, message="GameServerCluster",
+        proto.MESSAGE,
+        number=3,
+        message="GameServerCluster",
     )
     preview_time = proto.Field(
-        proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -182,8 +225,15 @@ class PreviewCreateGameServerClusterResponse(proto.Message):
             The target state.
     """
 
-    etag = proto.Field(proto.STRING, number=2,)
-    target_state = proto.Field(proto.MESSAGE, number=3, message=common.TargetState,)
+    etag = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    target_state = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=common.TargetState,
+    )
 
 
 class DeleteGameServerClusterRequest(proto.Message):
@@ -197,7 +247,10 @@ class DeleteGameServerClusterRequest(proto.Message):
             ``projects/{project}/locations/{location}/gameServerClusters/{cluster}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class PreviewDeleteGameServerClusterRequest(proto.Message):
@@ -214,9 +267,14 @@ class PreviewDeleteGameServerClusterRequest(proto.Message):
             preview.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     preview_time = proto.Field(
-        proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -231,8 +289,15 @@ class PreviewDeleteGameServerClusterResponse(proto.Message):
             The target state.
     """
 
-    etag = proto.Field(proto.STRING, number=2,)
-    target_state = proto.Field(proto.MESSAGE, number=3, message=common.TargetState,)
+    etag = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    target_state = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=common.TargetState,
+    )
 
 
 class UpdateGameServerClusterRequest(proto.Message):
@@ -253,10 +318,14 @@ class UpdateGameServerClusterRequest(proto.Message):
     """
 
     game_server_cluster = proto.Field(
-        proto.MESSAGE, number=1, message="GameServerCluster",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerCluster",
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -281,13 +350,19 @@ class PreviewUpdateGameServerClusterRequest(proto.Message):
     """
 
     game_server_cluster = proto.Field(
-        proto.MESSAGE, number=1, message="GameServerCluster",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerCluster",
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
     preview_time = proto.Field(
-        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -302,8 +377,15 @@ class PreviewUpdateGameServerClusterResponse(proto.Message):
             The target state.
     """
 
-    etag = proto.Field(proto.STRING, number=2,)
-    target_state = proto.Field(proto.MESSAGE, number=3, message=common.TargetState,)
+    etag = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    target_state = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=common.TargetState,
+    )
 
 
 class GameServerClusterConnectionInfo(proto.Message):
@@ -315,6 +397,7 @@ class GameServerClusterConnectionInfo(proto.Message):
         gke_cluster_reference (google.cloud.gaming_v1beta.types.GkeClusterReference):
             Reference to the GKE cluster where the game
             servers are installed.
+
             This field is a member of `oneof`_ ``cluster_reference``.
         namespace (str):
             Namespace designated on the game server
@@ -329,7 +412,10 @@ class GameServerClusterConnectionInfo(proto.Message):
         oneof="cluster_reference",
         message="GkeClusterReference",
     )
-    namespace = proto.Field(proto.STRING, number=5,)
+    namespace = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class GkeClusterReference(proto.Message):
@@ -348,7 +434,10 @@ class GkeClusterReference(proto.Message):
                cluster.
     """
 
-    cluster = proto.Field(proto.STRING, number=1,)
+    cluster = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GameServerCluster(proto.Message):
@@ -367,7 +456,7 @@ class GameServerCluster(proto.Message):
             Output only. The creation time.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The last-modified time.
-        labels (Sequence[google.cloud.gaming_v1beta.types.GameServerCluster.LabelsEntry]):
+        labels (Mapping[str, str]):
             The labels associated with this game server
             cluster. Each label is a key-value pair.
         connection_info (google.cloud.gaming_v1beta.types.GameServerClusterConnectionInfo):
@@ -380,15 +469,38 @@ class GameServerCluster(proto.Message):
             Human readable description of the cluster.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
     connection_info = proto.Field(
-        proto.MESSAGE, number=5, message="GameServerClusterConnectionInfo",
+        proto.MESSAGE,
+        number=5,
+        message="GameServerClusterConnectionInfo",
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=7,
     )
-    etag = proto.Field(proto.STRING, number=6,)
-    description = proto.Field(proto.STRING, number=7,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
