@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,11 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.gaming_v1beta.types import common
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.gaming.v1beta",
@@ -63,11 +62,26 @@ class ListGameServerConfigsRequest(proto.Message):
             https://cloud.google.com/apis/design/design_patterns#sorting_order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListGameServerConfigsResponse(proto.Message):
@@ -90,10 +104,18 @@ class ListGameServerConfigsResponse(proto.Message):
         return self
 
     game_server_configs = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="GameServerConfig",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerConfig",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=4,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=4,)
 
 
 class GetGameServerConfigRequest(proto.Message):
@@ -108,7 +130,10 @@ class GetGameServerConfigRequest(proto.Message):
             ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateGameServerConfigRequest(proto.Message):
@@ -128,10 +153,18 @@ class CreateGameServerConfigRequest(proto.Message):
             be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    config_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    config_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     game_server_config = proto.Field(
-        proto.MESSAGE, number=3, message="GameServerConfig",
+        proto.MESSAGE,
+        number=3,
+        message="GameServerConfig",
     )
 
 
@@ -147,7 +180,10 @@ class DeleteGameServerConfigRequest(proto.Message):
             ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/configs/{config}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ScalingConfig(proto.Message):
@@ -171,12 +207,24 @@ class ScalingConfig(proto.Message):
             applies.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    fleet_autoscaler_spec = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    fleet_autoscaler_spec = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     selectors = proto.RepeatedField(
-        proto.MESSAGE, number=4, message=common.LabelSelector,
+        proto.MESSAGE,
+        number=4,
+        message=common.LabelSelector,
+    )
+    schedules = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message=common.Schedule,
     )
-    schedules = proto.RepeatedField(proto.MESSAGE, number=5, message=common.Schedule,)
 
 
 class FleetConfig(proto.Message):
@@ -190,8 +238,14 @@ class FleetConfig(proto.Message):
             The name of the FleetConfig.
     """
 
-    fleet_spec = proto.Field(proto.STRING, number=1,)
-    name = proto.Field(proto.STRING, number=2,)
+    fleet_spec = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    name = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GameServerConfig(proto.Message):
@@ -209,7 +263,7 @@ class GameServerConfig(proto.Message):
             Output only. The creation time.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The last-modified time.
-        labels (Sequence[google.cloud.gaming_v1beta.types.GameServerConfig.LabelsEntry]):
+        labels (Mapping[str, str]):
             The labels associated with this game server
             config. Each label is a key-value pair.
         fleet_configs (Sequence[google.cloud.gaming_v1beta.types.FleetConfig]):
@@ -221,15 +275,39 @@ class GameServerConfig(proto.Message):
             The description of the game server config.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    fleet_configs = proto.RepeatedField(proto.MESSAGE, number=5, message="FleetConfig",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    fleet_configs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=5,
+        message="FleetConfig",
+    )
     scaling_configs = proto.RepeatedField(
-        proto.MESSAGE, number=6, message="ScalingConfig",
+        proto.MESSAGE,
+        number=6,
+        message="ScalingConfig",
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=7,
     )
-    description = proto.Field(proto.STRING, number=7,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
