@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.gaming_v1beta.types import common
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.gaming.v1beta",
@@ -70,11 +69,26 @@ class ListGameServerDeploymentsRequest(proto.Message):
             https://cloud.google.com/apis/design/design_patterns#sorting_order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListGameServerDeploymentsResponse(proto.Message):
@@ -97,10 +111,18 @@ class ListGameServerDeploymentsResponse(proto.Message):
         return self
 
     game_server_deployments = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="GameServerDeployment",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerDeployment",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=4,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=4,)
 
 
 class GetGameServerDeploymentRequest(proto.Message):
@@ -115,7 +137,10 @@ class GetGameServerDeploymentRequest(proto.Message):
             ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GetGameServerDeploymentRolloutRequest(proto.Message):
@@ -130,7 +155,10 @@ class GetGameServerDeploymentRolloutRequest(proto.Message):
             ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}/rollout``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateGameServerDeploymentRequest(proto.Message):
@@ -149,10 +177,18 @@ class CreateGameServerDeploymentRequest(proto.Message):
             to be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    deployment_id = proto.Field(proto.STRING, number=2,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    deployment_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     game_server_deployment = proto.Field(
-        proto.MESSAGE, number=3, message="GameServerDeployment",
+        proto.MESSAGE,
+        number=3,
+        message="GameServerDeployment",
     )
 
 
@@ -168,7 +204,10 @@ class DeleteGameServerDeploymentRequest(proto.Message):
             ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateGameServerDeploymentRequest(proto.Message):
@@ -190,10 +229,14 @@ class UpdateGameServerDeploymentRequest(proto.Message):
     """
 
     game_server_deployment = proto.Field(
-        proto.MESSAGE, number=1, message="GameServerDeployment",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerDeployment",
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -215,10 +258,14 @@ class UpdateGameServerDeploymentRolloutRequest(proto.Message):
     """
 
     rollout = proto.Field(
-        proto.MESSAGE, number=1, message="GameServerDeploymentRollout",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerDeploymentRollout",
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -234,7 +281,10 @@ class FetchDeploymentStateRequest(proto.Message):
             ``projects/{project}/locations/{location}/gameServerDeployments/{deployment}``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class FetchDeploymentStateResponse(proto.Message):
@@ -261,15 +311,25 @@ class FetchDeploymentStateResponse(proto.Message):
                 autoscalers created in the game server cluster.
         """
 
-        cluster = proto.Field(proto.STRING, number=1,)
+        cluster = proto.Field(
+            proto.STRING,
+            number=1,
+        )
         fleet_details = proto.RepeatedField(
-            proto.MESSAGE, number=2, message=common.DeployedFleetDetails,
+            proto.MESSAGE,
+            number=2,
+            message=common.DeployedFleetDetails,
         )
 
     cluster_state = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=DeployedClusterState,
+        proto.MESSAGE,
+        number=1,
+        message=DeployedClusterState,
+    )
+    unavailable = proto.RepeatedField(
+        proto.STRING,
+        number=2,
     )
-    unavailable = proto.RepeatedField(proto.STRING, number=2,)
 
 
 class GameServerDeployment(proto.Message):
@@ -288,7 +348,7 @@ class GameServerDeployment(proto.Message):
             Output only. The creation time.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The last-modified time.
-        labels (Sequence[google.cloud.gaming_v1beta.types.GameServerDeployment.LabelsEntry]):
+        labels (Mapping[str, str]):
             The labels associated with this game server
             deployment. Each label is a key-value pair.
         etag (str):
@@ -298,12 +358,33 @@ class GameServerDeployment(proto.Message):
             delpoyment.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    etag = proto.Field(proto.STRING, number=7,)
-    description = proto.Field(proto.STRING, number=8,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=7,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=8,
+    )
 
 
 class GameServerConfigOverride(proto.Message):
@@ -314,16 +395,25 @@ class GameServerConfigOverride(proto.Message):
     Attributes:
         realms_selector (google.cloud.gaming_v1beta.types.RealmSelector):
             Selector for choosing applicable realms.
+
             This field is a member of `oneof`_ ``selector``.
         config_version (str):
             The game server config for this override.
+
             This field is a member of `oneof`_ ``change``.
     """
 
     realms_selector = proto.Field(
-        proto.MESSAGE, number=1, oneof="selector", message=common.RealmSelector,
+        proto.MESSAGE,
+        number=1,
+        oneof="selector",
+        message=common.RealmSelector,
+    )
+    config_version = proto.Field(
+        proto.STRING,
+        number=100,
+        oneof="change",
     )
-    config_version = proto.Field(proto.STRING, number=100, oneof="change",)
 
 
 class GameServerDeploymentRollout(proto.Message):
@@ -357,14 +447,33 @@ class GameServerDeploymentRollout(proto.Message):
             ETag of the resource.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    default_game_server_config = proto.Field(proto.STRING, number=4,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    default_game_server_config = proto.Field(
+        proto.STRING,
+        number=4,
+    )
     game_server_config_overrides = proto.RepeatedField(
-        proto.MESSAGE, number=5, message="GameServerConfigOverride",
+        proto.MESSAGE,
+        number=5,
+        message="GameServerConfigOverride",
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=6,
     )
-    etag = proto.Field(proto.STRING, number=6,)
 
 
 class PreviewGameServerDeploymentRolloutRequest(proto.Message):
@@ -388,13 +497,19 @@ class PreviewGameServerDeploymentRolloutRequest(proto.Message):
     """
 
     rollout = proto.Field(
-        proto.MESSAGE, number=1, message="GameServerDeploymentRollout",
+        proto.MESSAGE,
+        number=1,
+        message="GameServerDeploymentRollout",
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
     preview_time = proto.Field(
-        proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
     )
 
 
@@ -413,9 +528,19 @@ class PreviewGameServerDeploymentRolloutResponse(proto.Message):
             The target state.
     """
 
-    unavailable = proto.RepeatedField(proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
-    target_state = proto.Field(proto.MESSAGE, number=4, message=common.TargetState,)
+    unavailable = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    target_state = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=common.TargetState,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
